<?php
/**
 * Handle plugin functionality related to admin side.
 *
 * @package WishGPT.
 */

namespace WishGPT;

/**
 * Handle plugin functionality related to admin side.
 *
 * @package Wish ChatGPT
 */
class Plugin_Admin {
	/**
	 * Class Constructor.
	 */
	public function __construct() {
		add_action( 'admin_menu', array( $this, 'register_admin_pages' ) );
		add_action( 'admin_init', array( $this, 'save_admin_settings' ) );
	}

	/**
	 * Register Admin Pages.
	 *
	 * @return void
	 */
	public function register_admin_pages() {
		add_menu_page(
			esc_html__( 'Wish GPT Settings', 'wishgpt' ),
			esc_html__( 'Wish GPT', 'wishgpt' ),
			'manage_options',
			'wishgpt_settings',
			array( $this, 'render_wishgpt_settings_page' ),
			'dashicons-editor-quote'
		);
	}

	/**
	 * Render WishGPT Settings Page.
	 *
	 * @return void
	 */
	public function render_wishgpt_settings_page() {
		wishgpt_template( 'settings-page' );
	}

	/**
	 * Save Admin Settings.
	 *
	 * @return void
	 */
	public function save_admin_settings() {

		$nonce = sanitize_key( $_POST['_wpnonce'] ?? '' );
		if ( empty( $nonce ) || ! wp_verify_nonce( $nonce, 'wishgpt_save_settings' ) ) {
			return;
		}

		$fields = array(
			'chatgpt_api_key',
			'chatgpt_max_tokens',
			'chatgpt_model',
			'max_generate',
		);

		foreach ( $fields as $field ) {
			$field_value = sanitize_text_field( wp_unslash( $_POST[ $field ] ?? '' ) );
			wishgpt_update_option( $field, $field_value );
		}

	}
}
new Plugin_Admin();
