<?php
/**
 * Handle plugin functionality related to public side.
 *
 * @package WishGPT.
 */

namespace WishGPT;

/**
 * Handle plugin functionality related to public side.
 *
 * @package Wish ChatGPT
 */
class Plugin_Public {
	/**
	 * Class Constructor.
	 */
	public function __construct() {
		add_action( 'init', array( $this, 'init_php_session' ) );
		add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_public_scripts' ) );
		add_shortcode( 'wishgpt', array( $this, 'render_form_shortcode' ) );
		add_action( 'wp_ajax_wishgpt_generate_wish', array( $this, 'generate_wish' ) );
		add_action( 'wp_ajax_nopriv_wishgpt_generate_wish', array( $this, 'generate_wish' ) );
	}

	/**
	 * Init PHP Session if not initated.
	 *
	 * @return void
	 */
	public function init_php_session() {
		if ( PHP_SESSION_NONE === session_status() || ! session_id() ) {
			session_start();
		}
	}

	/**
	 * Enqueue Script & Styles related to the plugin.
	 */
	public function enqueue_public_scripts() {
		global $post;
		if ( $post && has_shortcode( $post->post_content, 'wishgpt' ) ) {
			$script_vars = array(
				'ajaxUrl' => admin_url( 'admin-ajax.php' ),
			);
			wp_enqueue_style( 'wishgpt', WISHGPT_PLUGIN_URL . 'assets/css/wishgpt-public.css', array(), WISHGPT_PLUGIN_VERSION );
			wp_enqueue_script( 'wishgpt', WISHGPT_PLUGIN_URL . 'assets/js/wishgpt-public.js', array( 'jquery' ), WISHGPT_PLUGIN_VERSION, true );
			wp_localize_script( 'wishgpt', 'wishgpt', $script_vars );
		}
	}

	/**
	 * Render the Wish GPT Form.
	 *
	 * @param array|string|null $atts   Shortcode Attributes.
	 *
	 * @return string
	 */
	public function render_form_shortcode( $atts = array() ) : string {
		$atts = shortcode_atts(
			array(
				'prompt_id' => uniqid(),
			),
			$atts
		);
		return wishgpt_template( 'wishgpt-form', $atts, false );
	}

	/**
	 * Generate Chat GPT Response Based on our Provided Response.
	 */
	public function generate_wish() {

		$response = '';

		$nonce  = sanitize_key( $_POST['_wpnonce'] ?? '' );
		$prompt = sanitize_textarea_field( wp_unslash( $_POST['wish_prompt'] ?? '' ) );

		$usage = wishgpt_check_client_api_usage();
		if ( true !== $usage ) {
			wp_send_json(
				array(
					'error' => $usage,
				)
			);
		}

		if ( ! empty( $prompt ) && ! empty( $nonce ) && wp_verify_nonce( $nonce, 'wishgpt_generate_wish' ) ) {
			$response = wishgpt_chatgpt_api( $prompt );
		}

		wp_send_json(
			array(
				'output' => $response,
			)
		);
	}
}

new Plugin_Public();
