<?php
/**
 * Render Settings Page
 *
 * @package WishGPT
 */

$chatgpt_models = wishgpt_available_models();

$api_key       = wishgpt_option( 'chatgpt_api_key' );
$chatgpt_model = wishgpt_option( 'chatgpt_model', wishgpt_defualt_model() );
$max_tokens    = max( absint( wishgpt_option( 'chatgpt_max_tokens', 256 ) ), 100 );
$max_generate  = absint( wishgpt_option( 'max_generate', 0 ) );
?>
<div class="wrap">
	<h1><?php echo esc_html( get_admin_page_title() ); ?></h1>
	<form method="POST">
		<?php
			wp_nonce_field( 'wishgpt_save_settings' );
		?>
		<table class="form-table" role="presentation">
			<tr>
				<th scope="row">
					<label for="wishgpt_chatgpt_api_key">
						<?php esc_html_e( 'ChatGPT API Key', 'wishgpt' ); ?>
					</label>
				</th>
				<td>
					<input type="text" name="chatgpt_api_key" id="wishgpt_chatgpt_api_key" class="regular-text" value="<?php echo esc_attr( $api_key ); ?>">
				</td>
			</tr>
			<tr>
				<th scope="row">
					<label for="wishgpt_chatgpt_model">
						<?php esc_html_e( 'ChatGPT Model', 'wishgpt' ); ?>
					</label>
				</th>
				<td>
					<select name="chatgpt_model" id="wishgpt_chatgpt_model" class="regular-text">
						<?php
						foreach ( $chatgpt_models as $model_name ) {
							$model_selected = esc_attr( strtolower( $model_name ) ) === $chatgpt_model ? 'selected="selected"' : '';
							?>
							<option value="<?php echo esc_attr( strtolower( $model_name ) ); ?>" <?php echo $model_selected; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>>
								<?php echo esc_html( $model_name ); ?>
							</option>
							<?php
						}
						?>
					</select>
				</td>
			</tr>
			<tr>
				<th scope="row">
					<label for="wishgpt_chatgpt_max_tokens">
						<?php esc_html_e( 'ChatGPT Max Tokens per Request', 'wishgpt' ); ?>
					</label>
				</th>
				<td>
					<input type="number" min="100" name="chatgpt_max_tokens" id="wishgpt_chatgpt_max_tokens" class="regular-text" value="<?php echo absint( $max_tokens ); ?>">
				</td>
			</tr>
			<tr>
				<th scope="row">
					<label for="wishgpt_max_generate">
					<?php esc_html_e( 'Wishes Generate Limit', 'wishgpt' ); ?>
					</label>
				</th>
				<td>
					<input type="number" name="max_generate" id="wishgpt_max_generate" class="regular-text" value="<?php echo absint( $max_generate ); ?>">
				</td>
			</tr>
		</table>
		<p class="submit">
			<button type="submit" class="button button-primary">
				<?php esc_html_e( 'Save Settings', 'wishgpt' ); ?>
			</button>
		</p>
	</form>
</div>
